@@ -6,15 +6,17 @@ package SPVM::Sys::Socket::Ipv6_mreq;
 
 SPVM::Sys::Socket::Ipv6_mreq - struct ipv6_mreq in the C language
 
+=head1 Description
+
+The Sys::Socket::Ipv6_mreq class in L<SPVM> represents L<struct ipv6_mreq|https://linux.die.net/man/7/ipv6> in the C language.
+
 =head1 Usage
 
   use Sys::Socket::Ipv6_mreq;
 
-=head1 Description
+=head1 Details
 
-C<Sys::Socket::Ipv6_mreq> is the class for the C<struct ipv6_mreq> in the C language.
-
-This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
+This class is a pointer class. The pointer the instance has is set to a L<struct ipv6_mreq|https://linux.die.net/man/7/ipv6> object.
 
 =head1 Class Methods
 
@@ -22,7 +24,7 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 C<static method new : L<Sys::Socket::Ipv6_mreq|SPVM::Sys::Socket::Ipv6_mreq> ();>
 
-Create a new C<Sys::Socket::Ipv6_mreq> object.
+Create a new L<Sys::Socket::Ipv6_mreq|SPVM::Sys::Socket::Ipv6_mreq> object.
 
 =head1 Instance Methods
 
@@ -30,29 +32,31 @@ Create a new C<Sys::Socket::Ipv6_mreq> object.
 
 C<method DESTROY : void ();>
 
+The destructor.
+
 =head2 ipv6mr_multiaddr
 
 C<method ipv6mr_multiaddr : L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> ();>
 
-Get C<ipv6mr_multiaddr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object.
+Copies C<ipv6mr_multiaddr> and returns it.
 
 =head2 set_ipv6mr_multiaddr
 
 C<method set_ipv6mr_multiaddr : void ($interface : L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr>);>
 
-Set C<ipv6mr_multiaddr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object.
+Sets C<ipv6mr_multiaddr>.
 
 =head2 ipv6mr_interface
 
 C<method ipv6mr_interface : int ();>
 
-Get C<ipv6mr_interface>.
+Returns C<ipv6mr_interface>.
 
 =head2 set_ipv6mr_interface
 
 C<method set_ipv6mr_interface : void ($interface : int);>
 
-Set C<ipv6mr_interface>.
+Sets C<ipv6mr_interface>.
 
 =head1 Copyright & License
 
