@@ -6,19 +6,21 @@ package SPVM::Sys::Socket::Sockaddr::Un;
 
 SPVM::Sys::Socket::Sockaddr::Un - struct sockaddr_un in the C language
 
+=head1 Description
+
+The Sys::Socket::Sockaddr::Un class in L<SPVM> represents L<struct sockaddr_un|https://linux.die.net/man/7/unix> in the C language.
+
 =head1 Usage
 
   use Sys::Socket::Sockaddr::Un;
 
-=head1 Description
+=head1 Details
 
-C<Sys::Socket::Sockaddr::Un> is the class for the C<struct sockaddr_un> in the C language.
-
-This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
+This class is a pointer class. The pointer the instance has is set to a L<struct sockaddr_un|https://linux.die.net/man/7/unix> object.
 
 =head1 Inheritance
 
-This class inherits L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
+L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>
 
 =head1 Class Methods
 
@@ -26,6 +28,8 @@ This class inherits L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 C<static method new : L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> ();>
 
+Creates a new L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> object.
+
 =head1 Instance Methods
 
 =head2 DESTROY
@@ -38,13 +42,13 @@ The destructor.
 
 C<method sa_family : int ()>
 
-Gets C<sa_family>. This is the overriden method of the L<sa_family|SPVM::Sys::Socket::Sockaddr/"sa_family"> method in the Sys::Socket::Sockaddr class.
+Returns C<sa_family>.
 
 =head2 sun_family
 
 C<method sun_family : int ();>
 
-Gets C<sun_family>.
+Returns C<sun_family>.
 
 =head2 set_sun_family
 
@@ -56,7 +60,7 @@ Sets C<sun_family>.
 
 C<method sun_path : string ();>
 
-Copies C<sun_path>.
+Copies C<sun_path> and returns it.
 
 =head2 set_sun_path
 
@@ -68,7 +72,13 @@ Sets C<sun_path>.
 
 C<method size : int ()>
 
-The size of C<struct sockaddr_un>.
+Returns the size of C<struct sockaddr_un>.
+
+=head2 clone
+
+C<method clone : L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> ();>
+
+Clones this instance and returns it.
 
 =head1 Copyright & License
 
